@@ -33,60 +33,47 @@ if (na.rm) {
         group <- group[completeObs]
     }
 
-stor1 <- stor2 <- NULL
 
 if (method == "SW") {
-        for (i in 1:k) {
-        kk = shapiro.test(y[which(group == (levels(group)[i]))])
-        stor1 = c(stor1, kk$statistic)
-        stor2 = c(stor2, kk$p)
-    }
-method.name = "Shapiro-Wilk Normality Test"
+ kk <- tapply(y, group, shapiro.test)
+ stor1 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$statistic)))
+ stor2 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$p)))
+ method.name = "Shapiro-Wilk Normality Test"
 }
 
 if (method == "SF") {
-        for (i in 1:k) {
-        kk = sf.test(y[which(group == (levels(group)[i]))])
-        stor1 = c(stor1, kk$statistic)
-        stor2 = c(stor2, kk$p)
-    }
-method.name = "Shapiro-Francia Normality Test"
+  kk <- tapply(y, group, sf.test)
+  stor1 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$statistic)))
+  stor2 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$p)))
+  method.name = "Shapiro-Francia Normality Test"
 }
 
 if (method == "LT") {
-        for (i in 1:k) {
-        kk = lillie.test(y[which(group == (levels(group)[i]))])
-        stor1 = c(stor1, kk$statistic)
-        stor2 = c(stor2, kk$p)
-    }
-method.name = "Lilliefors (Kolmogorov-Smirnov) Normality Test"
+  kk <- tapply(y, group, lillie.test)
+  stor1 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$statistic)))
+  stor2 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$p)))
+  method.name = "Lilliefors (Kolmogorov-Smirnov) Normality Test"
 }
 
 if (method == "AD") {
-        for (i in 1:k) {
-        kk = ad.test(y[which(group == (levels(group)[i]))])
-        stor1 = c(stor1, kk$statistic)
-        stor2 = c(stor2, kk$p)
-    }
-method.name = "Anderson-Darling Normality Test"
+  kk <- tapply(y, group, ad.test)
+  stor1 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$statistic)))
+  stor2 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$p)))
+  method.name = "Anderson-Darling Normality Test"
 }
 
 if (method == "CVM") {
-        for (i in 1:k) {
-        kk = cvm.test(y[which(group == (levels(group)[i]))])
-        stor1 = c(stor1, kk$statistic)
-        stor2 = c(stor2, kk$p)
-    }
-method.name = "Cramer-von Mises Normality Test"
+  kk <- tapply(y, group, cvm.test)
+  stor1 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$statistic)))
+  stor2 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$p)))
+  method.name = "Cramer-von Mises Normality Test"
 }
 
 if (method == "PT") {
-        for (i in 1:k) {
-        kk = pearson.test(y[which(group == (levels(group)[i]))])
-        stor1 = c(stor1, kk$statistic)
-        stor2 = c(stor2, kk$p)
-    }
-method.name = "Pearson Chi-square Normality Test"
+  kk <- tapply(y, group, pearson.test)
+  stor1 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$statistic)))
+  stor2 <- as.numeric(unlist(lapply(1:k, function(i) kk[[i]]$p)))
+  method.name = "Pearson Chi-square Normality Test"
 }
 
    store = data.frame(matrix(NA, nrow = k, ncol = 4))
